import java.util.*;
import java.io.*;

import org.apache.xerces.parsers.DOMParser;
import org.xml.sax.SAXException;
import org.w3c.dom.*;

import com.example.schemamapper.SchemaMapper;

public class SchemaMap
{
	/**
	 * This application will map an XML document to a Java class
	 * based on an annotated schema. 
	 *
	 * @param args Array of parameters passed to the application
	 * via the command line.
	 */
	public static void main (String[] args)
	{
		String filename;
		
		// This object is the holder for the class that we create
		Object[] newClass = new Object[1];
		newClass[0] = null;
		
		System.out.println("SchemaMap - XMLDevCon 2000");
		System.out.println("");
		
		if (args.length < 1)
		{
			System.out.println("Usage: SchemaMap filename");
		}
		else
		{
			filename = args[0];
			DOMParser parser = new DOMParser();
			try
			{
				// Parse the instance file
				parser.parse(filename);
				org.w3c.dom.Document xdoc = parser.getDocument();
				
				// We need to get the namespace declaration of the
				// root element. We use this to determine which XML
				// schema to use.
				org.w3c.dom.Element ele = xdoc.getDocumentElement();
				String instNS = ele.getNamespaceURI();
				System.out.println("XML Instance: " + filename);
				System.out.println("Root Node: " + ele.getLocalName());
				System.out.println("Document Namespace: " + instNS);
				System.out.println("");
				
				SchemaMapper.processInstance(instNS, ele, newClass);
				
				System.out.println(newClass[0]);

			} 
			catch (SAXException se) 
			{
			    se.printStackTrace();
			} 
			catch (IOException ioe) {
			    ioe.printStackTrace();
			}
		}
		
	}
	
	// This routine creates a properties file
	static void boot()
	{
		Properties boot = new Properties();
		String encURI = SchemaMapper.encodeURI("http://www.example.com/person");
		boot.put(encURI, new String("person.xsd"));
		encURI = SchemaMapper.encodeURI("http://www.example.com/customer");
		boot.put(encURI, new String("customer.xsd"));
		
		try
		{
			FileOutputStream out = new FileOutputStream("/Schemas/Schema.dat");
			boot.save(out, "Schema Names");
			out.close();
		}
		catch (IOException ex)
		{
			ex.printStackTrace();
		}
	}		
}
